Index: trunk/ppImage/src/ppImageDetrendFringe.h
===================================================================
--- trunk/ppImage/src/ppImageDetrendFringe.h	(revision 10335)
+++ trunk/ppImage/src/ppImageDetrendFringe.h	(revision 13970)
@@ -9,4 +9,5 @@
 bool ppImageDetrendFringeMeasure(pmReadout *readout, // Readout to measure
                                  pmCell *fringe, // Fringe cell (each readout is a different component)
+				 const bool isResidual,
                                  const ppImageOptions *options // Options
     );
@@ -15,4 +16,5 @@
 bool ppImageDetrendFringeSolve(pmChip *scienceChip, // Chip with science
                                const pmChip *refChip, // Chip with reference fringes
+			       const bool isResidual,
                                const ppImageOptions *options // Options
     );
@@ -20,7 +22,14 @@
 // Generate fringe frame
 bool ppImageDetrendFringeGenerate(pmCell *science, // Science cell
-                                  pmCell *fringes // Fringe cell, one readout per fringe component
+                                  pmCell *fringes, // Fringe cell, one readout per fringe component
+				  const ppImageOptions *options // Options
     );
 
 
+bool ppImageDetrendFringeApply (pmConfig *config, // config
+				pmChip *chip, // science chip
+				const pmFPAview *inputView, // current view
+				const ppImageOptions *options // options
+);
+
 #endif
